'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

/**
 * Converts Ajv errors into human friendly errors hash
 */
exports.default = function (errors) {
  return errors.reduce(function (errors, error) {
    var dataPath = error.dataPath,
        message = error.message,
        keyword = error.keyword,
        _error$params = error.params,
        missingProperty = _error$params.missingProperty,
        type = _error$params.type;

    var path = keyword === 'required' ? dataPath + '.' + missingProperty : dataPath;
    var text = humanReadable(keyword, message, dataPath, missingProperty, type);
    var tokens = path.replace(/^\./, '').split('.');
    var lastToken = tokens.pop();

    var chunk = errors;
    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = tokens[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var name = _step.value;

        chunk = chunk[name] = chunk[name] || {};
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator.return) {
          _iterator.return();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }

    chunk[lastToken] = text;

    return errors;
  }, {});
};

function getNumFromStr(str) {
  return '' + str.match(/\d+/)[0];
}

function comparisonToStr(message) {
  return message.replace(' >= ', ' greater than or equal to ').replace(' <= ', ' less than or equal to ').replace(' > ', ' greater than ').replace(' < ', ' less than ');
}

/**
 * Converts an individual Ajv error into a human readable message
 */
function humanReadable(keyword, message, path, missingProperty, type) {
  switch (keyword) {
    case 'required':
      return 'is required';
    case 'pattern':
      return (/phone/.test(path) ? 'must be a valid phone number' : 'is malformed'
      );
    case 'format':
      return 'must be a valid ' + message.match(/"(.+?)"/)[1];
    case 'type':
      return 'must be a ' + type;
    case 'enum':
      return 'is not on the list';
    case 'minLength':
      {
        var length = getNumFromStr(message);
        return 'must be at least ' + length + ' character' + (length === 1 ? '' : 's') + ' long';
      }
    case 'maxLength':
      {
        var _length = getNumFromStr(message);
        return 'must be less than ' + _length + ' character' + (_length === 1 ? '' : 's') + ' long';
      }
    case 'minItems':
      {
        var _length2 = getNumFromStr(message);
        return 'must have at least ' + _length2 + ' item' + (_length2 === 1 ? '' : 's');
      }
    case 'maxItems':
      {
        var _length3 = getNumFromStr(message);
        return 'must have less than ' + _length3 + ' item' + (_length3 === 1 ? '' : 's');
      }
    case 'maximum':
    case 'minimum':
    default:
      return comparisonToStr(message.replace('should', 'must'));
  }
}